aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/gpu/GrGpu.h
diff options
context:
space:
mode:
authorGravatar bsalomon <bsalomon@google.com>2014-07-25 08:35:45 -0700
committerGravatar Commit bot <commit-bot@chromium.org>2014-07-25 08:35:45 -0700
commit6d3fe022d68fd6dd32c0fab30e24fa5a4f048946 (patch)
tree7af60205eeb7a7644e1bf4a8edfa0b1545619b0a /src/gpu/GrGpu.h
parent570c392a0056115e103b42c373a61e4e152ea92c (diff)
Rename GrGpuObject to GrGpuResource
R=robertphillips@google.com Author: bsalomon@google.com Review URL: https://codereview.chromium.org/418143004
Diffstat (limited to 'src/gpu/GrGpu.h')
-rw-r--r--src/gpu/GrGpu.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/gpu/GrGpu.h b/src/gpu/GrGpu.h
index 822deb13f0..b752f7c09c 100644
--- a/src/gpu/GrGpu.h
+++ b/src/gpu/GrGpu.h
@@ -249,28 +249,28 @@ public:
size_t rowBytes);
/**
- * Called to tell GrGpu that all GrGpuObjects have been lost and should
+ * Called to tell GrGpu that all GrGpuResources have been lost and should
* be abandoned. Overrides must call INHERITED::abandonResources().
*/
virtual void abandonResources();
/**
- * Called to tell GrGpu to release all GrGpuObjects. Overrides must call
+ * Called to tell GrGpu to release all GrGpuResources. Overrides must call
* INHERITED::releaseResources().
*/
void releaseResources();
/**
* Add object to list of objects. Should only be called by GrGpuObject.
* @param resource the resource to add.
*/
- void insertObject(GrGpuObject* object);
+ void insertObject(GrGpuResource* object);
/**
* Remove object from list of objects. Should only be called by GrGpuObject.
* @param resource the resource to remove.
*/
- void removeObject(GrGpuObject* object);
+ void removeObject(GrGpuResource* object);
// GrDrawTarget overrides
virtual void clear(const SkIRect* rect,
@@ -526,7 +526,7 @@ private:
enum {
kPreallocGeomPoolStateStackCnt = 4,
};
- typedef SkTInternalLList<GrGpuObject> ObjectList;
+ typedef SkTInternalLList<GrGpuResource> ObjectList;
SkSTArray<kPreallocGeomPoolStateStackCnt, GeometryPoolState, true> fGeomPoolStateStack;
ResetTimestamp fResetTimestamp;
uint32_t fResetBits;
@@ -249,28 +249,28 @@ public:
void releaseResources();
/**
- * Add object to list of objects. Should only be called by GrGpuObject.
+ * Add object to list of objects. Should only be called by GrGpuResource.
* @param resource the resource to add.
*/
@@ -249,28 +249,28 @@ public:
/**
- * Remove object from list of objects. Should only be called by GrGpuObject.
+ * Remove object from list of objects. Should only be called by GrGpuResource.
* @param resource the resource to remove.
*/